<?php
/**
 * $Horde: nag/index.php,v 1.7.2.2 2002/12/17 03:46:12 jon Exp $
 *
 * Copyright 2001 Jon Parise <jon@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

define('NAG_BASE', dirname(__FILE__));
$nag_configured = (@is_readable(NAG_BASE . '/config/conf.php') &&
                   @is_readable(NAG_BASE . '/config/html.php') &&
                   @is_readable(NAG_BASE . '/config/prefs.php'));

if (!$nag_configured) {
    require NAG_BASE . '/templates/index/notconfigured.inc';
    exit;
}

require NAG_BASE . '/list.php';
